##  Data Source Integration
We integrate data from multiple sources into Gainsight, ensuring comprehensive data coverage. The following table lists our primary data sources.
Data Source | Usage | Additional Information
---|---|---
Salesforce | Used to connect with our CRM system, allowing our Sales team to view Gainsight data |  [Salesforce Connector![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.gainsight.com%2Fgainsight_nxt%2FConnectors%2FCRM_Integrations%2FSalesforce_Connector "https://support.gainsight.com/gainsight_nxt/Connectors/CRM_Integrations/Salesforce_Connector")
Snowflake | Used to retrieve product usage data and customer engagement metrics, as well as track the adoption of SAP LeanIX |  [Snowflake Connector![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.gainsight.com%2Fgainsight_nxt%2FConnectors%2FDB_Based_Connectors%2FSnowflake_Connector "https://support.gainsight.com/gainsight_nxt/Connectors/DB_Based_Connectors/Snowflake_Connector")
Zendesk | Used to ingest support tickets and track their statuses |  [Zendesk Connector![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.gainsight.com%2Fgainsight_nxt%2FConnectors%2FSupport_Systems%2FZendesk_Connector "https://support.gainsight.com/gainsight_nxt/Connectors/Support_Systems/Zendesk_Connector")
Productboard | Used to collect and monitor product ideas sent to our Product team |  [Configure Product Requests![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.gainsight.com%2Fgainsight_nxt%2FProduct_Requests%2FProduct_Requests_-_Productboard_Integration%2FConfigure_Product_Requests "https://support.gainsight.com/gainsight_nxt/Product_Requests/Product_Requests_-_Productboard_Integration/Configure_Product_Requests")
Gainsight Customer Community | Used to track engagement in the [SAP LeanIX Community![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcommunity.leanix.net%2F "https://community.leanix.net/") |  [Customer Communities and Gainsight Integration - Admin Guide![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.gainsight.com%2Fgainsight_nxt%2FConnectors%2FConnect_Gainsight_Products%2FCustomer_Communities_%28CC%29%2FCustomer_Communities_and_Gainsight_Integration_-_Admin_Guide "https://support.gainsight.com/gainsight_nxt/Connectors/Connect_Gainsight_Products/Customer_Communities_\(CC\)/Customer_Communities_and_Gainsight_Integration_-_Admin_Guide")


